============
Citing Kwant
============

We provide Kwant as free software under a :doc:`BSD license <license>` as a
service to the physics community.  If you have used Kwant for work that has
lead to a scientific publication, please mention the fact that you used it
explicitly in the text body.  For example, you may add

  *the numerical calculations were performed using the Kwant code*

to the description of your numerical calculations.  In addition, we ask you to
cite the main paper that introduces Kwant:

  C. W. Groth, M. Wimmer, A. R. Akhmerov, X. Waintal,
  *Kwant: a software package for quantum transport*,
  `New J. Phys. 16, 063065 (2014)
  <https://iopscience.iop.org/1367-2630/16/6/063065/article>`_.


Other references we ask you to consider
---------------------------------------

If you have profited from the quantum transport functionality of Kwant, please
also cite the upcoming paper that describes the relevant algorithms. The
reference will also be added here once it is available.

Kwant owes much of its current performance to the use of the `MUMPS
<http://graal.ens-lyon.fr/MUMPS/>`_ library for solving systems of sparse linear
equations.  If you have done high-performance calculations, we suggest citing

  P. R. Amestoy, I. S. Duff, J. S. Koster, J. Y. L’Excellent, SIAM. J. Matrix
  Anal. & Appl. 23 (1), 15 (2001).

Finally, if you use the routine for generation of circular ensembles of random
matrices, please cite

  \F. Mezzadri, Notices Am. Math. Soc. 54, 592 (2007).
